pub fn is_probably_readerable(
html: &str,
options: Option<ReadabilityOptions>,
) -> boolExpand description
Check if a document is likely to be readable/parseable
pub fn is_probably_readerable(
html: &str,
options: Option<ReadabilityOptions>,
) -> boolCheck if a document is likely to be readable/parseable